# -*- coding: utf-8 -*-

import locale
import gettext

gettext.bindtextdomain('ows', '/usr/share/locale')
gettext.textdomain('ows')
locale.bindtextdomain('ows', '/usr/share/locale')
locale.textdomain('ows')
gettext.install('ows', '/usr/share/locale', unicode=1)


name = "ows"
long_name =  _('GNOME OSD Workspace Switcher')
version = "0.20100530"
image_dir = "/usr/share/pixmaps"
localedir = "/usr/share/locale"

copyright = "Copyright © 2010 David Villa Alises"
author = "David Villa Alises"
author_email = "<David.Villa@uclm.es>"

website = 'http://arco.inf-cr.uclm.es/~david.villa/ows.html'

license = "This program is free software; you can redistribute it and/or modify \
it under the terms of the GNU General Public License as published by \
the Free Software Foundation; either version 2 of the License, or \
(at your option) any later version. \n\n\
This program is distributed in the hope that it will be useful, but \
WITHOUT ANY WARRANTY; without even the implied warranty of \
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. \
See the GNU General Public License for more details. \n\n\
You should have received a copy of the GNU General Public License \
along with this program; if not, write to the Free Software Foundation, Inc., \
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA."
